summaryrefslogtreecommitdiffstats
path: root/content/public
diff options
context:
space:
mode:
authorpfeldman@chromium.org <pfeldman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-27 12:16:17 +0000
committerpfeldman@chromium.org <pfeldman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-27 12:16:17 +0000
commitf017cedd6df946c780de656ced1881ac108e5655 (patch)
treecfe3a35142777b6ad71733d902aeeb9715423f40 /content/public
parent5ec3ed8f21662b76ca763937f312e1964f1e3cb3 (diff)
downloadchromium_src-f017cedd6df946c780de656ced1881ac108e5655.zip
chromium_src-f017cedd6df946c780de656ced1881ac108e5655.tar.gz
chromium_src-f017cedd6df946c780de656ced1881ac108e5655.tar.bz2
DevTools: migrate remote debugging to the DevToolsAgentHost ids.
BUG=166824 TBR=yurys Review URL: https://codereview.chromium.org/11662024 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@174679 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/public')
-rw-r--r--content/public/browser/devtools_http_handler.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/content/public/browser/devtools_http_handler.h b/content/public/browser/devtools_http_handler.h
index 5ad9375..d01e801 100644
--- a/content/public/browser/devtools_http_handler.h
+++ b/content/public/browser/devtools_http_handler.h
@@ -18,25 +18,25 @@ class URLRequestContextGetter;
namespace content {
+class DevToolsAgentHost;
class DevToolsHttpHandlerDelegate;
-class RenderViewHost;
// This class is used for managing DevTools remote debugging server.
// Clients can connect to the specified ip:port and start debugging
// this browser.
class DevToolsHttpHandler {
public:
- // Interface responsible for mapping RenderViewHost instances to/from string
- // identifiers.
- class RenderViewHostBinding {
+ // Interface responsible for mapping DevToolsAgentHost instances to/from
+ // string identifiers.
+ class DevToolsAgentHostBinding {
public:
- virtual ~RenderViewHostBinding() {}
+ virtual ~DevToolsAgentHostBinding() {}
- // Returns the mapping of RenderViewHost to identifier.
- virtual std::string GetIdentifier(RenderViewHost* rvh) = 0;
+ // Returns the mapping of DevToolsAgentHost to identifier.
+ virtual std::string GetIdentifier(DevToolsAgentHost* agent_host) = 0;
- // Returns the mapping of identifier to RenderViewHost.
- virtual RenderViewHost* ForIdentifier(const std::string& identifier) = 0;
+ // Returns the mapping of identifier to DevToolsAgentHost.
+ virtual DevToolsAgentHost* ForIdentifier(const std::string& identifier) = 0;
};
// Returns frontend resource id for the given resource |name|.
@@ -53,12 +53,13 @@ class DevToolsHttpHandler {
// Automatically destroys the handler instance.
virtual void Stop() = 0;
// Set the RenderViewHostBinding instance. If no instance is provided the
// default implementation will be used.
- virtual void SetRenderViewHostBinding(RenderViewHostBinding* binding) = 0;
+ virtual void SetDevToolsAgentHostBinding(
+ DevToolsAgentHostBinding* binding) = 0;
// Returns the URL for the address to debug |render_view_host|.
- virtual GURL GetFrontendURL(RenderViewHost* render_view_host) = 0;
+ virtual GURL GetFrontendURL(DevToolsAgentHost* agent_host) = 0;
protected:
virtual ~DevToolsHttpHandler() {}
@@ -53,12 +53,13 @@ class DevToolsHttpHandler {
// Automatically destroys the handler instance.
virtual void Stop() = 0;
- // Set the RenderViewHostBinding instance. If no instance is provided the
+ // Set the DevToolsAgentHostBinding instance. If no instance is provided the
// default implementation will be used.